yarfox: Cross post from Mastodon to twitter
===========================================

Install
-------

Get ``Python3`` and insall ``yarfox`` with ``pip``.

Usage
-----

First, run ``yarfox setup`` and follow the instructions. This only needs to be done once.

Then:

* Run ``yarfox fetch`` to fetch your latest toots
* Run ``yarfox publish`` to cross post those toots to twitter

Feel free to use ``cron`` or ``systemd`` timers to automatically run these commands periodically.


Notes
-----

All the data fetched from Mastodon and twitter will be stored as plain JSON files inside ``~/.local/share/yarfox``, so you can
also use ``yarfox`` as some sort of backup.
